pub struct HashJoinBuffering {}Expand description
Looks for all the HashJoinExecs in the plan and places a BufferExec node with the configured capacity in the probe side:
┌───────────────────┐
│ HashJoinExec │
└─────▲────────▲────┘
┌───────┘ └─────────┐
│ │
┌────────────────┐ ┌─────────────────┐
│ Build side │ + │ BufferExec │
└────────────────┘ └────────▲────────┘
│
┌────────┴────────┐
│ Probe side │
└─────────────────┘Which allows eagerly pulling it even before the build side has completely finished.
Implementations