pub trait PhysicalOptimizerRule: Debug {
// Required methods
fn optimize(
&self,
plan: Arc<dyn ExecutionPlan>,
config: &ConfigOptions,
) -> Result<Arc<dyn ExecutionPlan>>;
fn name(&self) -> &str;
fn schema_check(&self) -> bool;
}Expand description
PhysicalOptimizerRule transforms one [‘ExecutionPlan’] into another which
computes the same results, but in a potentially more efficient way.
Use SessionState::add_physical_optimizer_rule to register additional
PhysicalOptimizerRules.
Required Methods
Sourcefn optimize(
&self,
plan: Arc<dyn ExecutionPlan>,
config: &ConfigOptions,
) -> Result<Arc<dyn ExecutionPlan>>
fn optimize( &self, plan: Arc<dyn ExecutionPlan>, config: &ConfigOptions, ) -> Result<Arc<dyn ExecutionPlan>>
Rewrite plan to an optimized form
Sourcefn schema_check(&self) -> bool
fn schema_check(&self) -> bool
A flag to indicate whether the physical planner should valid the rule will not change the schema of the plan after the rewriting. Some of the optimization rules might change the nullable properties of the schema and should disable the schema check.
Implementors
impl PhysicalOptimizerRule for AggregateStatistics
impl PhysicalOptimizerRule for CoalesceBatches
impl PhysicalOptimizerRule for CombinePartialFinalAggregate
impl PhysicalOptimizerRule for EnforceDistribution
impl PhysicalOptimizerRule for EnforceSorting
Performs optimizations based upon a series of subrules.
Refer to each subrule for detailed descriptions of the optimizations performed:
ensure_sorting, parallelize_sorts, replace_with_order_preserving_variants(),
and pushdown_sorts.
Subrule application is ordering dependent.
The subrule parallelize_sorts is only applied if repartition_sorts is enabled.